@@ -19,6 +19,7 @@ logger = logging.getLogger(__name__)
 PASSWORD_HASH_DUMMY_VALUE = 'DummyValue'
 SOURCE_NAME_RE = re.compile('^[A-Z][A-Z0-9-]*[A-Z0-9]$')
 RPKI_IRR_PSEUDO_SOURCE = 'RPKI'
+SOCKET_DEFAULT_TIMEOUT = 30
 
 # Note that sources are checked separately,
 # and 'access_lists' is always permitted
@@ -97,6 +98,7 @@ KNOWN_SOURCES_KEYS = {
     'export_timer',
     'nrtm_access_list',
     'nrtm_access_list_unfiltered',
+    'nrtm_query_serial_range_limit',
     'strict_import_keycert_objects',
     'rpki_excluded',
     'scopefilter_excluded',
@@ -397,6 +399,8 @@ class Configuration:
                 errors.append(f'Setting import_timer for source {name} must be a number.')
             if not str(details.get('export_timer', '0')).isnumeric():
                 errors.append(f'Setting export_timer for source {name} must be a number.')
+            if not str(details.get('nrtm_query_serial_range_limit', '0')).isnumeric():
+                errors.append(f'Setting nrtm_query_serial_range_limit for source {name} must be a number.')
 
             if details.get('nrtm_access_list'):
                 expected_access_lists.add(details.get('nrtm_access_list'))
