@@ -2,14 +2,18 @@ from collections import OrderedDict
 
 from typing import Set, List, Optional, Union
 
-from irrd.conf import PASSWORD_HASH_DUMMY_VALUE
+from irrd.conf import PASSWORD_HASH_DUMMY_VALUE, get_setting
 from irrd.utils.pgp import get_gpg_instance
 from .config import PASSWORD_HASHERS
 from .fields import (RPSLTextField, RPSLIPv4PrefixField, RPSLIPv4PrefixesField, RPSLIPv6PrefixField,
-                     RPSLIPv6PrefixesField, RPSLIPv4AddressRangeField, RPSLASNumberField, RPSLASBlockField,
-                     RPSLSetNameField, RPSLEmailField, RPSLDNSNameField, RPSLGenericNameField, RPSLReferenceField,
-                     RPSLReferenceListField, RPSLAuthField, RPSLRouteSetMembersField, RPSLChangedField)
+                     RPSLIPv6PrefixesField, RPSLIPv4AddressRangeField, RPSLASNumberField,
+                     RPSLASBlockField,
+                     RPSLSetNameField, RPSLEmailField, RPSLDNSNameField, RPSLGenericNameField,
+                     RPSLReferenceField,
+                     RPSLReferenceListField, RPSLAuthField, RPSLRouteSetMembersField,
+                     RPSLChangedField, RPSLURLField)
 from .parser import RPSLObject, UnknownRPSLObjectClassException
+from ..utils.validators import parse_as_number, ValidationError
 
 RPSL_ROUTE_OBJECT_CLASS_FOR_IP_VERSION = {
     4: 'route',
@@ -56,6 +60,19 @@ class RPSLAsSet(RPSLObject):
         ('source', RPSLGenericNameField()),
     ])
 
+    def clean_for_create(self) -> bool:
+        if get_setting('compatibility.permit_non_hierarchical_as_set_name'):
+            return True
+
+        first_segment = self.pk().split(':')[0]
+        try:
+            parse_as_number(first_segment)
+            return True
+        except ValidationError as ve:
+            self.messages.error('AS set names must be hierarchical and the first component must '
+                                f'be an AS number, e.g. "AS65537:AS-EXAMPLE": {str(ve)}')
+        return False
+
 
 class RPSLAutNum(RPSLObject):
     fields = OrderedDict([
@@ -149,6 +166,7 @@ class RPSLInet6Num(RPSLObject):
         ('tech-c', RPSLReferenceField(lookup_key=True, multiple=True, referring=['role', 'person'])),
         ('rev-srv', RPSLTextField(optional=True, multiple=True)),
         ('status', RPSLTextField()),
+        ('geofeed', RPSLURLField(optional=True)),
         ('remarks', RPSLTextField(optional=True, multiple=True)),
         ('notify', RPSLEmailField(optional=True, multiple=True)),
         ('mnt-by', RPSLReferenceListField(lookup_key=True, multiple=True, referring=['mntner'])),
@@ -167,6 +185,7 @@ class RPSLInetnum(RPSLObject):
         ('tech-c', RPSLReferenceField(lookup_key=True, multiple=True, referring=['role', 'person'])),
         ('rev-srv', RPSLTextField(optional=True, multiple=True)),
         ('status', RPSLTextField()),
+        ('geofeed', RPSLURLField(optional=True)),
         ('remarks', RPSLTextField(optional=True, multiple=True)),
         ('notify', RPSLEmailField(optional=True, multiple=True)),
         ('mnt-by', RPSLReferenceListField(lookup_key=True, multiple=True, referring=['mntner'])),
